@@ -464,7 +464,7 @@ sub replace_all_variables_in_pathes
 
         my $key;
 
-        foreach $key (keys %{$variableshashref})
+        foreach $key (sort { length ($b) <=> length ($a) } keys %{$variableshashref})
         {
             my $value = $variableshashref->{$key};
             
@@ -793,6 +793,7 @@ sub add_variables_to_allvariableshashref
 
     if ( $installer::globals::patch ) { $variableshashref->{'PRODUCTADDON'} = $installer::globals::patchaddon; }
     elsif ( $installer::globals::languagepack ) { $variableshashref->{'PRODUCTADDON'} = $installer::globals::languagepackaddon; }
+    elsif ( $installer::globals::helppack ) { $variableshashref->{'PRODUCTADDON'} = $installer::globals::helppackpackaddon; }
     else { $variableshashref->{'PRODUCTADDON'} = ""; }
 
     my $localbuild = $installer::globals::build;
@@ -806,6 +807,7 @@ sub add_variables_to_allvariableshashref
     $variableshashref->{'PRODUCTMINOR'} = $localminor;
 
     $variableshashref->{'PRODUCTBUILDID'} = $installer::globals::buildid;
+    $variableshashref->{'SYSTEM_LIBTEXTCAT_DATA'} = $ENV{'SYSTEM_LIBTEXTCAT_DATA'} , if( defined $ENV{'SYSTEM_LIBTEXTCAT_DATA'} && $ENV{'SYSTEM_LIBTEXTCAT_DATA'} ne "" );
 }
 
 1;
